@@ -17,7 +17,9 @@ import copy
 import re
 import warnings
 from functools import reduce
+from typing import Union
 
+import datetime as dt
 import pandas as pd
 
 from gs_quant.api.gs.backtests_xasset.response_datatypes.backtest_datatypes import TransactionCostConfig, \
@@ -221,8 +223,6 @@ class EquityVolEngine(object):
                             'Error: HedgeAction: PeriodicTrigger frequency must be the same as trade_duration')
                     if not action.risk == EqDelta:
                         check_results.append('Error: HedgeAction: risk type must be EqDelta')
-                    if not trigger.trigger_requirements.frequency == '1b':
-                        check_results.append('Error: HedgeAction: frequency must be \'1b\'')
                 elif isinstance(action, (a.ExitPositionAction, a.ExitTradeAction)):
                     continue
                 else:
@@ -305,11 +305,7 @@ class EquityVolEngine(object):
                 transaction_cost.trade_cost_model = TradingCosts(cls.__map_tc_model(action.transaction_cost),
                                                                  cls.__map_tc_model(action.transaction_cost_exit))
             elif isinstance(action, a.HedgeAction):
-                if trigger.trigger_requirements.frequency == '1b':
-                    frequency = 'Daily'
-                else:
-                    raise RuntimeError('unrecognised hedge frequency')
-                hedge = DeltaHedgeParameters(frequency=frequency)
+                hedge = DeltaHedgeParameters(frequency=trigger.trigger_requirements.frequency)
                 transaction_cost.hedge_cost_model = TradingCosts(cls.__map_tc_model(action.transaction_cost),
                                                                  cls.__map_tc_model(action.transaction_cost_exit))
 
@@ -373,10 +369,13 @@ class TenorParser(object):
     # match expiration dates expressed as 3m@listed
     expiry_regex = '(.*)@(.*)'
 
-    def __init__(self, expiry: str):
+    def __init__(self, expiry: Union[str, dt.date]):
         self.expiry = expiry
 
     def get_date(self):
+        if isinstance(self.expiry, dt.date):
+            return self.expiry
+
         parts = re.search(self.expiry_regex, self.expiry)
         if parts:
             return parts.group(1)
@@ -384,6 +383,9 @@ class TenorParser(object):
             return self.expiry
 
     def get_mode(self):
+        if isinstance(self.expiry, dt.date):
+            return None
+
         parts = re.search(self.expiry_regex, self.expiry)
         if parts:
             return parts.group(2)
